/*
 * $Id: ReadOnlyGrammarPool.java,v 1.3 2002/07/12 22:56:13 Bear Exp $
 *
 * Copyright 2002 Kohsuke Kawaguchi, Inc. All Rights Reserved.
 * 
 * Use is subject to license terms.
 */
package org.kohsuke.jarv.xerces;

import org.apache.xerces.xni.grammars.Grammar;
import org.apache.xerces.xni.grammars.XMLGrammarDescription;
import org.apache.xerces.xni.grammars.XMLGrammarPool;

/**
 * An immutable XMLGrammarPool.
 * 
 * @author Kohsuke Kawaguchi (kk@kohsuke.org)
 */
class ReadOnlyGrammarPool implements XMLGrammarPool {

    private final Grammar[] grammars;
    
    ReadOnlyGrammarPool( Grammar[] _grammars ) {
        this.grammars = _grammars;
    }
    
    ReadOnlyGrammarPool( Grammar g ) {
        this( new Grammar[]{g} );
    }

    /**
     * Just returns the pre-defined fixed set of grammars.
     */
    public Grammar[] retrieveInitialGrammarSet(String grammarType) {
        // TODO: check the grammar type to make sure it's XML Schema.
        return grammars;
    }

    /**
     * Do not "currupt" our master grammars by newly found ones.
     */
    public void cacheGrammars(String grammarType, Grammar[] grammars) {
    }

    /**
     * We don't know how to load grammars, so let the schema validator
     * do it.
     */
    public Grammar retrieveGrammar(XMLGrammarDescription desc) {
        return null;
    }
    
    // this pool is read-only, so there is no use for lock.
    public void unlockPool() {}
    public void lockPool() {}
    
    public void clear() {}
}
